@@ -1,7 +1,7 @@
 package Git::Bunch;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.47'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.48'; # VERSION
 
 use 5.010001;
 use strict;
@@ -886,7 +886,7 @@ Git::Bunch - Manage gitbunch directory (directory which contain git repos)
 
 =head1 VERSION
 
-This document describes version 0.47 of Git::Bunch (from Perl distribution Git-Bunch), released on 2015-08-17.
+This document describes version 0.48 of Git::Bunch (from Perl distribution Git-Bunch), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -932,14 +932,12 @@ See also L<File::RsyBak>, which I wrote to backup everything else.
 
 =head2 check_bunch(%args) -> [status, msg, result, meta]
 
-{en_US Check status of git repositories inside gitbunch directory}.
+Check status of git repositories inside gitbunch directory.
 
-{en_US 
 Will perform a 'git status' for each git repositories inside the bunch and
 report which repositories are clean/unclean.
 
 Will die if can't chdir into bunch or git repository.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -947,47 +945,42 @@ Arguments ('*' denotes required arguments):
 
 =item * B<exclude_files> => I<bool>
 
-{en_US Exclude files from processing}.
+Exclude files from processing.
 
-{en_US 
 This only applies to C<sync_bunch> operations. Operations like C<check_bunch> and
 C<exec_bunch> already ignore these and only operate on git repos.
-}
 
 =item * B<exclude_non_git_dirs> => I<bool>
 
-{en_US Exclude non-git dirs from processing}.
+Exclude non-git dirs from processing.
 
-{en_US 
 This only applies to and C<sync_bunch> operations. Operations like C<check_bunch>
 and C<exec_bunch> already ignore these and only operate on git repos.
-}
 
 =item * B<exclude_repos> => I<array[str]>
 
-{en_US Exclude some repos from processing}.
+Exclude some repos from processing.
 
 =item * B<exclude_repos_pat> => I<str>
 
-{en_US Specify regex pattern of repos to exclude}.
+Specify regex pattern of repos to exclude.
 
 =item * B<include_repos> => I<array[str]>
 
-{en_US Specific git repos to sync, if not specified all repos in the bunch will be processed}.
+Specific git repos to sync, if not specified all repos in the bunch will be processed.
 
 =item * B<include_repos_pat> => I<str>
 
-{en_US Specify regex pattern of repos to include}.
+Specify regex pattern of repos to include.
 
 =item * B<repo> => I<str>
 
-{en_US Only process a single repo}.
+Only process a single repo.
 
 =item * B<sort> => I<str> (default: "-commit-timestamp")
 
-{en_US Order entries in bunch}.
+Order entries in bunch.
 
-{en_US 
 If sorting is enabled, the repos will be sorted first by some ordering. One
 use-case for this is to allow more recently committed-to repos to be processed
 first (using C<-commit-timestamp> or C<-db-commit-timestamp>).
@@ -1017,11 +1010,10 @@ C<name> (or C<-name>) simply compares the repos' names. This is one of the faste
 methods.
 
 C<rand> randomizes the order of repos, so you get different ordering in each run.
-}
 
 =item * B<source>* => I<str>
 
-{en_US Directory to check}.
+Directory to check.
 
 =back
 
@@ -1039,12 +1031,10 @@ Return value:  (any)
 
 =head2 exec_bunch(%args) -> [status, msg, result, meta]
 
-{en_US Execute a command for each repo in the bunch}.
+Execute a command for each repo in the bunch.
 
-{en_US 
 For each git repository in the bunch, will chdir to it and execute specified
 command.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -1052,51 +1042,46 @@ Arguments ('*' denotes required arguments):
 
 =item * B<command>* => I<str>
 
-{en_US Command to execute}.
+Command to execute.
 
 =item * B<exclude_files> => I<bool>
 
-{en_US Exclude files from processing}.
+Exclude files from processing.
 
-{en_US 
 This only applies to C<sync_bunch> operations. Operations like C<check_bunch> and
 C<exec_bunch> already ignore these and only operate on git repos.
-}
 
 =item * B<exclude_non_git_dirs> => I<bool>
 
-{en_US Exclude non-git dirs from processing}.
+Exclude non-git dirs from processing.
 
-{en_US 
 This only applies to and C<sync_bunch> operations. Operations like C<check_bunch>
 and C<exec_bunch> already ignore these and only operate on git repos.
-}
 
 =item * B<exclude_repos> => I<array[str]>
 
-{en_US Exclude some repos from processing}.
+Exclude some repos from processing.
 
 =item * B<exclude_repos_pat> => I<str>
 
-{en_US Specify regex pattern of repos to exclude}.
+Specify regex pattern of repos to exclude.
 
 =item * B<include_repos> => I<array[str]>
 
-{en_US Specific git repos to sync, if not specified all repos in the bunch will be processed}.
+Specific git repos to sync, if not specified all repos in the bunch will be processed.
 
 =item * B<include_repos_pat> => I<str>
 
-{en_US Specify regex pattern of repos to include}.
+Specify regex pattern of repos to include.
 
 =item * B<repo> => I<str>
 
-{en_US Only process a single repo}.
+Only process a single repo.
 
 =item * B<sort> => I<str> (default: "-commit-timestamp")
 
-{en_US Order entries in bunch}.
+Order entries in bunch.
 
-{en_US 
 If sorting is enabled, the repos will be sorted first by some ordering. One
 use-case for this is to allow more recently committed-to repos to be processed
 first (using C<-commit-timestamp> or C<-db-commit-timestamp>).
@@ -1126,11 +1111,10 @@ C<name> (or C<-name>) simply compares the repos' names. This is one of the faste
 methods.
 
 C<rand> randomizes the order of repos, so you get different ordering in each run.
-}
 
 =item * B<source>* => I<str>
 
-{en_US Directory to check}.
+Directory to check.
 
 =back
 
@@ -1148,16 +1132,14 @@ Return value:  (any)
 
 =head2 sync_bunch(%args) -> [status, msg, result, meta]
 
-{en_US Synchronize bunch to another bunch}.
+Synchronize bunch to another bunch.
 
-{en_US 
 For each git repository in the bunch, will perform a 'git pull/push' for each
 branch. If repository in destination doesn't exist, it will be rsync-ed first
 from source. When 'git pull' fails, will exit to let you fix the problem
 manually.
 
 For all other non-git repos, will simply synchronize by one-way rsync.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -1165,9 +1147,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<backup> => I<bool>
 
-{en_US Whether doing backup to target}.
+Whether doing backup to target.
 
-{en_US 
 This setting lets you express that you want to perform synchronizing to a backup
 target, and that you do not do work on the target. Thus, you do not care about
 uncommitted or untracked files/dirs in the target repos (might happen if you
@@ -1176,13 +1157,11 @@ is turned on, the function will first do a C<git clean -f -d> (to delete
 untracked files/dirs) and then C<git checkout .> (to discard all uncommitted
 changes). This setting will also implicitly turn on C<create_bare> setting
 (unless that setting has been explicitly enabled/disabled).
-}
 
 =item * B<create_bare_target> => I<bool>
 
-{en_US Whether to create bare git repo when target does not exist}.
+Whether to create bare git repo when target does not exist.
 
-{en_US 
 When target repo does not exist, gitbunch can either copy the source repo using
 C<rsync> (the default, if this setting is undefined), or it can create target
 repo with C<git init --bare> (if this setting is set to 1), or it can create
@@ -1195,66 +1174,58 @@ Creating bare repos are apt for backup purposes since they are more
 space-efficient.
 
 Non-repos will still be copied/rsync-ed.
-}
 
 =item * B<delete_branch> => I<bool> (default: 0)
 
-{en_US Whether to delete branches in dest repos not existing in source repos}.
+Whether to delete branches in dest repos not existing in source repos.
 
 =item * B<exclude_files> => I<bool>
 
-{en_US Exclude files from processing}.
+Exclude files from processing.
 
-{en_US 
 This only applies to C<sync_bunch> operations. Operations like C<check_bunch> and
 C<exec_bunch> already ignore these and only operate on git repos.
-}
 
 =item * B<exclude_non_git_dirs> => I<bool>
 
-{en_US Exclude non-git dirs from processing}.
+Exclude non-git dirs from processing.
 
-{en_US 
 This only applies to and C<sync_bunch> operations. Operations like C<check_bunch>
 and C<exec_bunch> already ignore these and only operate on git repos.
-}
 
 =item * B<exclude_repos> => I<array[str]>
 
-{en_US Exclude some repos from processing}.
+Exclude some repos from processing.
 
 =item * B<exclude_repos_pat> => I<str>
 
-{en_US Specify regex pattern of repos to exclude}.
+Specify regex pattern of repos to exclude.
 
 =item * B<include_repos> => I<array[str]>
 
-{en_US Specific git repos to sync, if not specified all repos in the bunch will be processed}.
+Specific git repos to sync, if not specified all repos in the bunch will be processed.
 
 =item * B<include_repos_pat> => I<str>
 
-{en_US Specify regex pattern of repos to include}.
+Specify regex pattern of repos to include.
 
 =item * B<repo> => I<str>
 
-{en_US Only process a single repo}.
+Only process a single repo.
 
 =item * B<rsync_opt_maintain_ownership> => I<bool> (default: 0)
 
-{en_US Whether or not, when rsync-ing from source, we use -a (= -rlptgoD) or -rlptD (-a minus -go)}.
+Whether or not, when rsync-ing from source, we use -a (= -rlptgoD) or -rlptD (-a minus -go).
 
-{en_US 
 Sometimes using -a results in failure to preserve permission modes on
 sshfs-mounted filesystem, while -rlptD succeeds, so by default we don't maintain
 ownership. If you need to maintain ownership (e.g. you run as root and the repos
 are not owned by root), turn this option on.
-}
 
 =item * B<sort> => I<str> (default: "-commit-timestamp")
 
-{en_US Order entries in bunch}.
+Order entries in bunch.
 
-{en_US 
 If sorting is enabled, the repos will be sorted first by some ordering. One
 use-case for this is to allow more recently committed-to repos to be processed
 first (using C<-commit-timestamp> or C<-db-commit-timestamp>).
@@ -1284,15 +1255,14 @@ C<name> (or C<-name>) simply compares the repos' names. This is one of the faste
 methods.
 
 C<rand> randomizes the order of repos, so you get different ordering in each run.
-}
 
 =item * B<source>* => I<str>
 
-{en_US Directory to check}.
+Directory to check.
 
 =item * B<target>* => I<str>
 
-{en_US Destination bunch}.
+Destination bunch.
 
 =back
 
@@ -1328,7 +1298,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Git-Bunch>
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Git-Bunch>.
+Source repository is at L<https://github.com/perlancar/perl-Git-Bunch>.
 
 =head1 BUGS
 
